/**
 * 基于json文件的持久化缓存的控制接口
 */
export default interface Cache {
  /**
   * 获取缓存内容,如果不存在或已过期则返回 null
   * 
   * @param {String} key 缓存的键
   * @return {any}
   */
  get(key: string): any;

  /**
   * 设置缓存
   * 
   * @param {String} key 缓存的键
   * @param {any} value 缓存的值
   * @param {Object} opts
   *  - {Number} opts.expries  有效时长, 毫秒为单位, 如 1分钟为 60 * 1000
   * 
   * @return {boolean}
   */
  set(key: string, value: any, opts?: object): boolean;

  /**
   * 清理缓存中指定的key内容
   * 
   * @param {String} key 缓存的键
   * @return {boolean}
   */
  remove(key: string): boolean;
}
