import * as ufx from "../ufx";

/**
 * UFX框架底层依赖的检测接口
 */
export default interface Check {
  /**
   * 获取core模块的package.json内容
   * 
   * @return {null|Object}
   */
  getCoreInfo(): any;

  /**
   * 安装core模块
   * @desc 安装模块前会先检查并初始化core目录
   * 
   * @param coreName 模块名,默认为ufx-core
   * @param {Object} opts npminstall模块的Options
   */
  installCore(coreName: string, opts?: object): Promise<void>;

  /**
   * 检测cli的版本，根据检查结果提示是否要更新
   * 
   * @return {Object} ufx.checkResult
   */
  cli(): Promise<ufx.checkResult>;

  /**
   * 检测ufx-base的版本，根据检查结果提示是否要更新
   * 
   * @return {Object} ufx.checkResult
   */
  base(): Promise<ufx.checkResult>;

  /**
   * 检测ufx-core的版本，并根据检测结果自动下载更新
   * @param {Boolen} forceUpdae 标记是否强制更新
   * 
   * @return {Object} ufx.checkResult
   */
  core(forceUpdae?: boolean): Promise<ufx.checkResult>;


  /**
   * 检测 Cli&Base 的版本
   * @param {String} type 类型：'base' | 'cli'
   * 
   * @return {Object} ufx.checkResult
   */
  getUpdateStatus(type: 'base' | 'cli'): Promise<ufx.checkResult>;

  /**
   * 打印 Cli&Base 模块安装提示信息
   * @param {Object} opts ufx.checkResult
   * @private
   */
  printUpdateTips(opts: ufx.checkResult): void;

  /**
   * 打印Core模块的更新提示
   * 
   * @param {Object} opts ufx.checkResult
   * @private
   */
  printCoreUpdateTips(opts: ufx.checkResult): void;
}
