export type EnvType = 'intranet' | 'extranet';

/**
 * UFX的环境控制接口
 */
export interface Env {
  /**
   * 检查当前网络环境是否为阿里内网
   * 
   * @param {Url} host
   * - 如果host === https://registry.antfin-inc.com/，则根据网络接口请求状态来返回检查结果；
   * - 如果host不是阿里registry的host，则直接返回false
   * 
   * @return {Promise<boolean>}
   */
  isAlibabanet(host?: string): Promise<boolean>;

  /**
   * 检查是否为内网环境
   * @desc 优先判断process.env[`${nameSpace}_ENV`] 变量，其次是cache标记，最后是通过网络请求判断。
   * 
   * @return {Promise<boolean>}
   */
  isIntranet(): Promise<boolean>;
  
  /**
   * 根据内网络区分来获取npm地址
   * 
   * @returns {Promise<string>}
   */
  getRegistry(): Promise<string>;

  /**
   * 设置framework的运行环境,并将状态写入到 CACHE_FILE 文件里
   * @param {String} env 内外网环境变量,枚举可选的值有: intranet | extranet
   * @private
   */
  setEnv(env: EnvType): void;

  /**
   * 重置env模块缓存
   * 
   * @private
   */
  resetEnv(): void;
}
