/**
 * UFX的本地库缓存目录控制接口
 */
export default interface Home {
  /**
   * 缓存初始化
   * 
   * @desc 初始化本地缓存home目录、home的package.json以及core缓存目录
   * @private
   */
  init(): void;

  /**
   * 初始化home目录
   * @private
   */
  initHome(): void;

  /**
   * 初始化home的package.json
   * @private
   */
  initHomePkg(): void;

  /**
   * 初始化core目录
   * @private
   */
  initCore(): void;

  /**
   * 清理core缓存
   * @private
   */
  cleanCoreDir(): void;

  /**
   * 清理cache缓存文件
   * @private
   */
  cleanCacheFile(): void;

  /**
   * 获取home路径
   * @return {String} 返回路径字符串
   */
  getHomePath(): string;

  /**
   * 获取core的缓存目录
   * @return {String} 返回路径字符串
   */
  getCorePath(): string;

  /**
   * 获取core的node_modules目录
   * @return {String} 返回路径字符串
   */
  getCoreModulePath(): string;

  /**
   * 获取缓存文件路径
   * @returns {String} 返回路径字符串
   */
  getCacheFilePath(): string;
}
