/**
 * npm.run默认支持的命令类型
 */
export type npmCommond = 'install' | 'uninstall' | 'update' | 'link';

/**
 * UFX Base框架的npm包管理接口
 */
export interface Npm {
  /**
   * 获取npm的执行js的路径
   * @param {String} name 文件名
   * 
   * @return {String} 执行js的路径
   */
  get(name?: npmCommond): string;
  /**
   * 安装 npm 包
   * @param {String} installer 安装工具路径
   * @param {string|Array} paths  需要安装的包或包列表,需要带版本号直接在包名后面 @ 版本号即可, 留空安装当前目录下的 package.json 依赖
   * @param {Object} options npminstall模块的Options
   * @see https://www.npmjs.com/package/npminstall
   * 
   * @return {Promise}
   */
  run(installer: string, paths: string | any[], options: object): Promise<any>;

  /**
   * 安装 npm 包
   * @param {string|Array} pkg 需要安装的包或包列表, 需要带版本号直接在包名后面 @ 版本号即可
   * @param {Object} options npminstall模块的Options
   *
   * @return {Promise}
   */
  install(pkg: string | any[], options?: object): Promise<any>;

  /**
   * 获取最新的npm包信息
   * @param {string} name npm的package.name
   * @param {Object} options npminstall模块的Options
   * 
   * @return {Promise}
   */
  getNpmInfo(name: string, options?: object): Promise<any>;
}
