
/**
 * 网络请求返回结果的描述接口
 */
export interface NetData {
  status: boolean;
  data: any;
  error?: any;
}

/**
 * UFX基础通用类库
 */
export interface Utils  {
  /**
   * 通过get请求获取数据
   * @param {Object} options
   * - {Url} options.url 目标url
   * - {Number} options.timeout 过期时长,默认5秒
   * - {Object} options 参考 request.options
   * 
   * @return {Promise<NetData>}
   */
  getApiData(options: any): Promise<NetData>;
  /**
   * 通过请求测试url来检查网络状态
   * - {Url} testUrl 测试的url
   * - {Number} timeout 超时时长，默认3秒
   * 
   * @return {Promise<boolean>}
   */
  checkNetStatus(testUrl: string, timeout?: number): Promise<boolean>;
  /**
   * 获取传入路径下的js文件名
   * @param {String} dir 目标路径
   * 
   * @return {Array}
   */
  getFileNames(dir: string): string[];
}
