import { Chalk } from 'chalk';
import * as ufx from "./ufx";
import { base } from "./base";
import * as fs from "./fs";

import * as coreUtils from './core/utils';
import * as coreError from './core/error';
import * as coreModule from './core/module';
import * as coreContainer from './core/container';
import coreRuntime from './core/runtime';
import coreSetting from './core/setting';
import coreConfig from './core/config';
import coreHome from './core/home';
import coreNpm from './core/npm';

export { default as KitLog } from "./core/kitlog";
export { KitContext,KitModules } from './core/container';

export module core {
  type Modules = {
    (name: 'container'): KitContainer;
    (name: 'config'): Config;
    (name: 'error'): ErrorHandles;
    (name: 'fs'): Fs;
    (name: 'home'): Home;
    (name: 'module'): Module;
    (name: 'npm'): Npm;
    (name: 'runtime'): Runtime;
    (name: 'setting'): Setting;
    (name: 'utils'): Utils;
    (name: 'helper'): { render: () => string; }
    (name: 'task'): {
      run: (command: string, options?: any) => Promise<boolean>
    };
  }

  type Commands = {
    (this: Core, name: string): Promise<void>;
  }

  // CORE构造函数接口
  export interface Core extends ufx.UfxClass {
    /**
     * 获取base内置功能模块
     * @param {string} name modules目录下的 base-[name] 模块
     * @return {base.Modules}
     */
    getBaseModule: base.Modules;
    /**
     * 获取core内置的功能模块
     * @param {string} name ./modules目录下的core-[name]模块名
     * @return {Modules}
     */
    getCoreModule: Modules
    /**
     * 获取core内置的命令command
     * @param {string} name ./commands目录下的[name]模块名
     * @return {Commands}
     */
    getCoreCommand: Commands;

    /**
     * core模块的package信息
     */
    coreInfo: any;

    /**
     * core模块的log处理函数
     */
    baseLog: ufx.logFn
  }

  export interface Config extends coreConfig {}
  export interface Home extends coreHome {}
  export interface Npm extends coreNpm {}
  export interface Setting extends coreSetting {}
  export interface Runtime extends coreRuntime {}
  export interface KitContainer extends coreContainer.KitContainer {}

  export type DirCopy = fs.DirCopy;
  export interface Fs extends fs.ufxFs {}

  export type ufxModules = coreModule.ufxModules;
  export interface Module extends coreModule.Module {}

  export type CoreTypeError = coreError.CoreTypeError;
  export type ErrorList = coreError.ErrorList;
  export interface ErrorHandles extends coreError.ErrorHandles { }
  
  export type FormatArgv = coreUtils.FormatArgv;
  export type ModuleType = coreUtils.ModuleType;
  export type ListItem = coreUtils.ListItem;
  export interface Utils extends coreUtils.Utils { }
}
  

export interface Runtime extends coreRuntime {
  /**
   * 读取套件模块的接口
  
  * @property {Object} commands: KitCommands;
  * @property {Object} modules?: KitModules;
  * @property {Object} [name:string]: KitModules
  * 
  */
  kit?: coreContainer.KitContext
}
