import coreRuntime from './runtime';

/**
 * kit套件的控制接口
 */
export interface KitContainer {
  /**
   * 初始化kit套件的IOC容器
   * 
   * @desc 如果套件没有安装，则会自动检测并安装
   * @private
   */
  init(): Promise<void>;

  /**
   * 套件模块容器
   * 
   * @return {Object}
   * @property {Object} commands 存放套件的命令
   * @property {Object} modules 存放套件的模块
   */
  context: KitContext

  /**
   * 读取套件模块的package.json
   * @param {String} name 套件名
   * @return {Object}
   */
  requireKitPkgInfo(kitName: string): any;

  /**
   * 获取全部kit模块
   * @param {String} name 套件名
   * @return {KitContext}
   */
  requireKit(kitName: string): KitContext;

  /**
   * 设置套件中函数模块的context
   * @param {Object<coreRuntime>} ctx 模块的runtime context
   * 
   * @return {KitContext}
   */
  setKitContext(ctx: coreRuntime): KitContext;
}

export interface KitCommands {
  [name: string]: (this: coreRuntime) => void | Promise<void>;
}

export interface KitModules {
  [name: string]: any;
}

export interface KitContext {
  commands: KitCommands;
  modules?: KitModules;
  [name: string]: KitModules
}
