// 异常对象
export interface CoreTypeError extends TypeError {
  code?: string;
}

// 缓存Framework运行周期内的异常
export type ErrorList = CoreTypeError[];

/**
 * 异常处理控制
 */
export interface ErrorHandles {
  /**
   * 注册需要处理的Error
   * @param {core.CoreTypeError | core.ErrorList} err
   */
  register(handle: CoreTypeError): void;

  /**
   * 判断自动修复error的机制是否需要重试
   */
  checkRetry(): boolean;

  /**
   * 读取 error 列表
   * @return {Array} error 列表
   */  
  getErrorList(): ErrorList;

  /**
   * 清理错误列表
   */
  clearError(): Promise<boolean>;

  /**
   * 处理模块不存在的异常，尝试自动修复
   * @param {core.CoreTypeError} err
   * @return {Boolean}
   */
  noFoundHandle(err: CoreTypeError): Promise<boolean>;

  /**
   * 默认的异常处理
   * @param {core.CoreTypeError} err
   * @return {Boolean}
   */
  defaultHandle(err: CoreTypeError): Promise<boolean>;
}
