import * as ufx from '../ufx';
import { ListItem } from './utils'

export interface ufxModules {
  kit: ListItem[];
  mod: ListItem[]
}

/**
 * UFX模块控制类
 */
export interface Module {
  /**
   * 检查模块
   * @param {String} moduleName 模块名
   * @return {Promise<ufx.checkResult>}
   */ 
  checkModule(kitName: string): Promise<ufx.checkResult>;

  /**
   * 检查并安装模块
   * @param {String} moduleName 模块名
   * @return {Promise<ufx.checkResult>}
   */
  checkAndInstallModule(kitName: string): Promise<ufx.checkResult>;

  /**
   * 获取${nameSpace}模块及package信息
   * @desc 如果模块不存在或者版本教旧，则自动升级模块
   * 
   * @param {String} moduleName 模块名
   * @return {Promise<any>}
   */
  requireModule(moduleName: string): Promise<any>;

  /**
   * 加载${nameSpace}模块
   * @param {String} moduleName 模块名
   * @return {Promise<null|function>}
   */
  require(moduleName: string): Promise<any>;

  /**
   * 获取模块最新的package信息
   * @param {String} moduleName 模块名
   * @return {Promise<any>}
   */
  requirePkgInfo(moduleName: string): Promise<any>;

  /**
   * 获取${nameSpace}模块及package信息
   * @desc 如果模块不存在或者版本教旧，则自动升级模块
   * @param {String} fullName 模块名，支持缩写, eg: kit-rax = ${nameSpace}-kit-rax = @scope/${nameSpace}-kit-rax。
   * @return {Promise<any>}
   */
  getModule(moduleName: string): Promise<any>;

  /**
   * 判断模块在本地缓存中是否存在
   * @param {String} name 模块名
   * @return {Promise<boolean>}
   */
  modLocalExist(name: string): Promise<boolean>;

  /**
   * 获取本地已经安装的模块列表
   * @return {Promise<ListItem[]>}
   */
  getLocalModuleList(): Promise<ListItem[]>;

  /**
   * 获取npm仓库中的模块列表
   * @desc 读取远端仓库的列表后, 本地会将列表清单保存 cache, 在缓存未过期前都是返回cache中的名单以提高性能, 默认cache缓存时长为3小时。
   * @return {Promise<ListItem[]>}
   */
  getOnlineModuleList(keyword?: string): Promise<ListItem[]>;

  /**
   * 获取套件列表
   * @return {Promise<ListItem[]>}
   */
  getKitList(): Promise<ListItem[]>;

  /**
   * 获取ufx框架全部模块或套件
   * @return {Promise<ufxModules>}
   */
  getAllModules(): Promise<ufxModules>;
}
