import * as baseNpm from '../base/npm'

/**
 * UFX Core的npm包管理接口
 */
export default interface Npm extends baseNpm.Npm {
  /**
   * 卸载npm包
   * @param {String|Array} pkg
   * @param {Object} options npminstall模块的Options
   * @see https://www.npmjs.com/package/npminstall
   * @return {Promise<Object>}
   */
  uninstall(pkg: string | any[], options?: object): Promise<any>;

  /**
   * 升级npm包
   * @param {String|Array} pkg
   * @param {Object} options npminstall模块的Options
   * @return {Promise<Object>}
   */ 
  update(pkg: string | any[], options?: object): Promise<any>;

  /**
   * 安装当前项目的依赖
   * @param {Object} options npminstall模块的Options
   * @return {Promise<Object>}
   */
  installDependencies(options?: object): Promise<any>;

  /**
   * 安装框架的模块
   * @param {string} pkg 模块名/列表
   * @param {object} options npminstall模块的Options
   * @return {Promise<Object>}
   */
  installModules(pkg: string | any[], options?: any): Promise<any>;

  /**
   * 卸载UFX缓存中的模块
   * @param {string} pkg 模块名/列表
   * @param {object} options npminstall模块的Options
   * @returns {Promise<Object>}
   */
  uninstallModules(pkg: string | any[], options?: any): Promise<any>;

  /**
   * 判断远程npm仓库中的[name]模块是否存在
   * @param {String} name 模块名
   * @param {Object} options npminstall模块的Options
   * @returns {Promise<boolean>}
   */
  check(name: string, options?: any): Promise<boolean>;
}
