import * as fs from "fs-extra";

export * from "fs-extra";

export interface DirCopy {
  src: string;
  dist: string;
  encoding?: string;
  ignore?: string[];
  silent?: boolean;
  filenameTransformer?: (name?: string) => string;
}

export interface ufxFs {
  dirCopy(options: DirCopy): void;
  fileCopy(options: DirCopy): void;
  [key: string]: any;
}

/**
 * 复制目录及目录下的文件
 * @desc 此方法是文件目录全拷贝，递归算法
 * 
 * @param {object: core.DirCopy} options
 * - {String} options.src 源文件的绝对路径
 * - {String} options.dist 目标的绝对路径
 * - {Boolean} options.silent 静默操作，不输出log
 * - {Array} options.ignore 数组, 类似 gitignore 的写法
 * - {Function} options.filenameTransformer 函数, 文件名转换函数列表
 * - {String} options.encoding 默认 utf-8
 * 
 * @example
 * ```js
 * this.dirCopy({
 *   src: tplRoot,
 *   dist: cwd,
 *   ignore: [ 'node_modules', '.DS_Store', '.idea'],
 *   filenameTransformer(n: string) {
 *     let name = n;
 *     if (name.startsWith('__')) {
 *       name = name.replace('__', '');
 *     } else if (name.startsWith('_')) {
 *       name = name.replace('_', '.');
 *     } else if (name.startsWith('.ufx')) {
 *       name = name.replace('ufx', this.nameSpace);
 *     }
 *     return name;
 *   },
 * });
 * ```
 * 
 */
export function dirCopy(options: DirCopy): void;

/**
 * 复制文件
 * 
 * @param {object} options:<DirCopy>
 * - {String} options.src 目标文件的绝对路径
 * - {String} options.dist 绝对路径，可以是文件绝对路径，也可以是该文件所在的目录
 * - {Boolean} options.silent 静默操作，不输出log
 * - {Array} options.ignore 数组, 类似 gitignore 的写法
 * - {Function} options.filenameTransformer 函数, 文件名转换函数列表
 * - {String} options.encoding 默认 utf-8
 * 
 */
export function fileCopy(options: DirCopy): void;
