import minimist from 'minimist';
import { Log } from './base/log';

export * from './base/log'

// 动态泛类型
export type ufxObj<T> = {
  [name: string]: T;
}

// 命令参数行解析后的对象
export type parsedArgs = minimist.ParsedArgs;

// UFX框架的运行环境接口
export interface RuntimeEnv {
  // 用于判断是否为内网
  isIntranet(): boolean;

  // 自定义的npm registry host
  npmRegistry: string;

  // 强制标记是否为阿里内网
  isAlibabanet?: boolean;

  // npm的scope
  scope?: string;
}

/**
 * UFX基类的初始化参数接口
 */
export interface BaseContext {
  nameSpace: string;
  cliInfo?: any;
  baseInfo?: any;
  args?: parsedArgs;
  env?: RuntimeEnv;
  npmTag?: string;
  isDebug?: boolean;
}

// npm模块检测的返回结果
export type checkResult = {
  // 检查状态
  status: boolean;
  // 检查结果的升级类型，如：安装 install，升级 update，不需升级 noupdate
  type?: string | null;
  // 最新的npm模块package信息
  pkgInfo?: any;
  // 本地或当前的npm模块package信息
  oldPkgInfo?: any;
}

/**
 * UFX框架的基类
 */
export interface UfxClass extends BaseContext {
  /**
   * module缓存的容器对象
   */
  modules: ufxObj<any>;
  /**
   * command缓存的容器对象
   */
  commands: ufxObj<any>;

  /**
   * 当前模块的log API
   */
  log: Log;

  /**
   * 当前运行的命令名
   */
  currCommand: string;

  /**
   * 基类对外曝露的执行接口
   */
  run(cmd?: string | null): void;

  /**
   * 设置当前类的运行时上下文
   * @param {String} type 'modules'|'commands'
   * @private
   */
  setContext(type: 'modules' | 'commands'): void;

  /**
   * 处理当前运行的命令
   * @param cmd 即将运行命令，支持别名或缩写
   * @private
   */
  setCurrCommand(cmd?: string): void;
}
